# Example Package

This package helps to get coordinates of object from image as listed list of x,y.
It depends on Numpy, opencv, matplotlib.

INSTALLATION 


pip install imgplotter



usage

python<br>
from imgplotter.point import plotter
<br>
plotter(r'path')
<br>

Features which can be added : 
1. Scale image to reduce coordinate size variable pass only to add
2. Colour & styling
